# pymlt
python machine learning template

## links
https://pypi.org/project/pymlt  
https://ghcr.io/benvliet/pymlt  
https://pepy.tech/projects/pymlt  # todo: add badges  
https://codecov.io/gh/benvliet/pymlt  # todo: add to pipeline  

## project structure

```
.
├── .github/        # specifies how github actions runs ci/cd pipelines
├── docs/           # documentation and cheat sheets
├── notebooks/      # example notebooks
├── scripts/        # example scripts
├── src/            # source code
│   ├── pymlt/      # pymlt package modules
├── tests/          # pytest 
├── .gitignore      # ...
├── Dockerfile      # specifies how to build a docker container
├── LICENSE         # license information
├── pyproject.toml  # project configuration
├── README.md       # this file
└── uv.lock         # dependency lock file
```
